@@ -916,6 +916,19 @@ class Worker(Process):
                     if self.config["SAVE_INTERMITTENT"]:
                         self.job.save_entity()
                 else:
+                    # Processing discontinued due to stop signal, failed step
+                    # function etc
+                    self.worker_adapter.update_state(
+                        self.api_entity,
+                        ValidStates.IDLE,
+                        bot_entity=self.bot_entity,
+                    )
+                    if ValidStates.ACTIVE.value not in [
+                        worker.state for worker in self.bot_entity.workers
+                    ]:
+                        self.bot_adapter.update_state(
+                            self.bot_entity, ValidStates.IDLE
+                        )
                     break
             if not self.config["SKIP_FINAL_SAVE"]:
                 self.job.save_entity()
@@ -951,13 +964,6 @@ class Worker(Process):
             if self.job.get_entity(entity_type, entity_guid):
                 process_as_far_as_possible(process_functions)
         else:
-            self.worker_adapter.update_state(
-                self.api_entity, ValidStates.IDLE, bot_entity=self.bot_entity
-            )
-            if ValidStates.ACTIVE.value not in [
-                worker.state for worker in self.bot_entity.workers
-            ]:
-                self.bot_adapter.update_state(self.bot_entity, ValidStates.IDLE)
             self._delete_message()
 
     def run(self):
