@@ -52,3 +52,21 @@ class ItemAddManyEntity(QalxListEntity):
     """
 
     _data_key = "items"
+
+    @property
+    def items_(self):
+        """
+        Helper to allow easier lookup for items.  A user can continue to do
+        `resp['items']` should they choose - but using this property leads to
+        neater code.
+
+        Usage: `resp.items_`
+
+        :return: dict
+        :raises: KeyError if `items` key doesn't exist on ItemAddManyEntity
+        """
+        # We have to use a property rather than an instance attribute even though
+        # it's slower because using an instance attribute would cause problems
+        # if `add_many` has some items that can't be added (as these get removed
+        # from the `items` dict after instantition)
+        return self[self._data_key]
