@@ -265,7 +265,7 @@ class AWSProvider(BaseProvider):
         try:
             resp = client.create_stack(
                 StackName=stack_name,
-                TemplateURL=item["file"]["url"],
+                TemplateURL=item.file.url,
                 OnFailure=on_failure,
                 EnableTerminationProtection=True,
                 Capabilities=["CAPABILITY_NAMED_IAM"],
